import { QueryKey, UseQueryOptions, UseInfiniteQueryOptions, UseQueryResult, UseInfiniteQueryResult } from "react-query";
import { Query, QuerySnapshot, DocumentData, Firestore, SnapshotOptions, FirestoreError } from "firebase/firestore";
import { GetSnapshotSource, UseFirestoreHookOptions, WithIdField } from "./index";
export declare type NamedQueryPromise<T> = () => Promise<Query<T> | null>;
export declare type NamedQuery<T = DocumentData> = Query<T> | NamedQueryPromise<T>;
export declare type QueryType<T> = Query<T> | NamedQuery<T>;
export declare function resolveQuery<T>(query: QueryType<T>): Promise<Query<T>>;
export declare function namedQuery<T>(firestore: Firestore, name: string): NamedQuery<T>;
export declare function useFirestoreQuery<T = DocumentData, R = QuerySnapshot<T>>(key: QueryKey, query: QueryType<T>, options?: UseFirestoreHookOptions, useQueryOptions?: Omit<UseQueryOptions<QuerySnapshot<T>, FirestoreError, R>, "queryFn">): UseQueryResult<R, FirestoreError>;
export declare function useFirestoreQueryData<T = DocumentData, R = WithIdField<T>[]>(key: QueryKey, query: QueryType<T>, options?: UseFirestoreHookOptions & SnapshotOptions, useQueryOptions?: Omit<UseQueryOptions<WithIdField<T>[], FirestoreError, R>, "queryFn">): UseQueryResult<R, FirestoreError>;
export declare function useFirestoreQueryData<ID extends string, T = DocumentData, R = WithIdField<T, ID>[]>(key: QueryKey, query: QueryType<T>, options?: UseFirestoreHookOptions & SnapshotOptions & {
    idField: ID;
}, useQueryOptions?: Omit<UseQueryOptions<WithIdField<T, ID>[], FirestoreError, R>, "queryFn">): UseQueryResult<R, FirestoreError>;
export declare function useFirestoreInfiniteQuery<T = DocumentData, R = QuerySnapshot<T>>(key: QueryKey, initialQuery: Query<T>, getNextQuery: (snapshot: QuerySnapshot<T>) => Query<T> | undefined, options?: {
    source?: GetSnapshotSource;
}, useInfiniteQueryOptions?: Omit<UseInfiniteQueryOptions, "queryFn" | "getNextPageParam">): UseInfiniteQueryResult<R, FirestoreError>;
export declare function useFirestoreInfiniteQueryData<T = DocumentData, R = WithIdField<T>[]>(key: QueryKey, initialQuery: Query<T>, getNextQuery: (data: T[]) => Query<T> | undefined, options?: {
    source?: GetSnapshotSource;
} & SnapshotOptions, useInfiniteQueryOptions?: Omit<UseInfiniteQueryOptions<WithIdField<T>[], FirestoreError, R>, "queryFn" | "getNextPageParam">): UseInfiniteQueryResult<R, FirestoreError>;
export declare function useFirestoreInfiniteQueryData<ID extends string, T = DocumentData, R = WithIdField<T, ID>[]>(key: QueryKey, initialQuery: Query<T>, getNextQuery: (data: T[]) => Query<T> | undefined, options?: {
    source?: GetSnapshotSource;
} & SnapshotOptions & {
    idField: ID;
}, useInfiniteQueryOptions?: Omit<UseInfiniteQueryOptions<WithIdField<T, ID>[], FirestoreError, R>, "queryFn" | "getNextPageParam">): UseInfiniteQueryResult<R, FirestoreError>;
